@@ -30,7 +30,6 @@ class BaseData:
     * datasource_base_url           Data Source Base Url
     * current_environment           Current AWS Environment. Available environments are:
                                     local, dev, staging, production. Default: production
-    * settings                      Snatch Settings.
     """
 
     tax_id: Optional[str] = None
@@ -40,11 +39,7 @@ class BaseData:
     payload: Optional[Dict[str, Any]] = None
     timeit: Optional[float] = None
     datasource_base_url: Optional[str] = None
-    settings: Optional[Cut] = None
-
-    @property
-    def current_environment(self) -> str:
-        return self.settings["current_environment"]
+    current_environment: Optional[Cut] = None
 
     def find_current_status(self, max_days_old: int):
         """Find current Status for Data.
