@@ -48,6 +48,10 @@ class BaseSnatch:
 
     def __post_init__(self):
         self.settings = get_settings()
+        cnpj = CNPJ()
+        if not cnpj.validate(self.tax_id):
+            raise ValueError("Invalid TaxId")
+        self.tax_id = only_numbers(self.tax_id)
 
     @property
     def authorization_token(self) -> str:
@@ -64,25 +68,6 @@ class BaseSnatch:
             "Authorization": f"Token {self.authorization_token}",
         }
 
-    @property
-    def tax_id(self) -> str:  # noqa
-        """Return current TaxId."""
-        return self._tax_id
-
-    @tax_id.setter
-    def tax_id(self, data: str):
-        """Save current TaxId for DataSource Integration.
-
-        Will check a valid CNPJ first and convert to numbers only.
-
-        :param data: TaxId (must be a valid CNPJ)
-        :return: None
-        """
-        cnpj = CNPJ()
-        if not cnpj.validate(data):
-            raise ValueError("Invalid TaxId")
-        self._tax_id = only_numbers(data)  # noqa
-
     def _waiter(self, timeout: Optional[int] = None):
         if not timeout:
             timeout = self.default_timeout
